-- Order the eras into a temp table
CREATE TABLE Eras_Temp AS SELECT * FROM Eras WHERE ID <= (SELECT ID FROM Eras WHERE Type='ERA_RENAISSANCE') ORDER BY ID ASC;
INSERT INTO Eras_Temp SELECT * FROM ERAS WHERE Type='ERA_ENLIGHTENMENT';
INSERT INTO Eras_Temp SELECT * FROM Eras WHERE ID > (SELECT ID FROM Eras WHERE Type='ERA_RENAISSANCE') AND Type!='ERA_ENLIGHTENMENT' ORDER BY ID ASC;
UPDATE Eras_Temp SET ID=rowid-1;

-- Copy the ordered eras back into the main table and remove the temp table 
DELETE FROM Eras;
INSERT INTO Eras SELECT * FROM Eras_Temp ORDER BY rowid ASC;
DROP TABLE Eras_Temp;

-- Give ourselves some more abbrevations
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_7_ABBREV', 'VIII');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_8_ABBREV', 'IX');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_9_ABBREV', 'X');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_10_ABBREV', 'XI');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_11_ABBREV', 'XII');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_12_ABBREV', 'XIII');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_13_ABBREV', 'XIV');
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) VALUES('TXT_KEY_ERA_14_ABBREV', 'XV');

-- Create a table to hold the names of the eras  
CREATE TABLE IF NOT EXISTS Eras_Text(
  ID INTEGER NOT NULL,
  Type TEXT NOT NULL,
  Lang TEXT NOT NULL,
  Desc TEXT DEFAULT NULL,
  Short TEXT DEFAULT NULL
);

-- Grab all the names of the eras
DELETE FROM Eras_Text;
INSERT INTO Eras_Text(ID, Type, Lang, Desc, Short)
  SELECT e.ID, e.Type, 'EN_US', t1.Text, t2.Text
  FROM Eras e, Language_EN_US t1, Language_EN_US t2
  WHERE e.Description=t1.Tag AND e.ShortDescription=t2.Tag;

-- Update the era names and abbreviations as required by the tech tree and 'pedia
UPDATE Eras SET Description='TXT_KEY_ERA_'||ID, ShortDescription='TXT_KEY_ERA_'||ID||'_SHORT', Abbreviation='TXT_KEY_ERA_'||ID||'_ABBREV';

-- Update the text entries corresponding to the newl
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) SELECT 'TXT_KEY_ERA_'||e.ID, et.Desc FROM Eras e, Eras_Text et WHERE e.Type = et.Type AND et.Lang='EN_US';
INSERT OR REPLACE INTO Language_EN_US(Tag, Text) SELECT 'TXT_KEY_ERA_'||e.ID||'_SHORT', et.Short FROM Eras e, Eras_Text et WHERE e.Type = et.Type AND et.Lang='EN_US';
DROP TABLE Eras_Text;

-- Make a hole in the tech tree
UPDATE Technologies SET GridX=GridX+2
WHERE GridX >= (SELECT GridX FROM Technologies WHERE ERA IN (SELECT Type FROM Eras WHERE ID > (SELECT ID FROM Eras WHERE Type='ERA_RENAISSANCE')) ORDER BY GridX LIMIT 1);
